/* Copyright 2009 Marcel Overdijk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.grails.samples.sakila

class ActorController extends BaseController {

    def index = { redirect(action: "list", params: params) }
    
    static allowedMethods = [save: "POST", update: "POST", delete: "POST", search: "POST"]

    def list = {
        if (params.max) params.max = Math.min(params.max.toInteger(), 100)
        restoreState([max: 10, offset: 0, sort: "id", order: "asc", search: ""])
        def actorInstanceList = Actor.createCriteria().list(params) {
            if (params.search) {
                or {
                    ilike("firstName", "%${params.search}%")
                    ilike("lastName", "%${params.search}%")
                }
            }
        }
        [actorInstanceList: actorInstanceList]
    }

    def search = {
        redirect(action: "list", params: [offset: 0, search: params.q])
    }

    def create = {
        def actorInstance = new Actor()
        actorInstance.properties = params
        return [actorInstance: actorInstance]
    }

    def save = {
        def actorInstance = new Actor(params)
        if (!actorInstance.hasErrors() && actorInstance.save()) {
            flash.message = "actor.created"
            flash.args = [actorInstance]
            flash.defaultMessage = "Actor ${actorInstance} created"
            redirect(action: "show", id: actorInstance.id)
        }
        else {
            render(view: "create", model: [actorInstance: actorInstance])
        }
    }

    def show = {
        def actorInstance = Actor.get(params.id)
        if (!actorInstance) {
            flash.message = "actor.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Actor not found with id ${params.id}"
            redirect(action: "list")
        }
        else {
            return [actorInstance: actorInstance]
        }
    }

    def edit = {
        def actorInstance = Actor.get(params.id)
        if (!actorInstance) {
            flash.message = "actor.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Actor not found with id ${params.id}"
            redirect(action: "list")
        }
        else {
            return [actorInstance: actorInstance]
        }
    }

    def update = {
        def actorInstance = Actor.get(params.id)
        if (actorInstance) {
            actorInstance.properties = params
            if (!actorInstance.hasErrors() && actorInstance.save()) {
                flash.message = "actor.updated"
                flash.args = [actorInstance]
                flash.defaultMessage = "Actor ${actorInstance} updated"
                redirect(action: "show", id: actorInstance.id)
            }
            else {
                render(view: "edit", model: [actorInstance: actorInstance])
            }
        }
        else {
            flash.message = "actor.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Actor not found with id ${params.id}"
            redirect(action: "edit", id: params.id)
        }
    }

    def delete = {
        def actorInstance = Actor.get(params.id)
        if (actorInstance) {
            def actorInstanceToString = actorInstance.toString()
            try {
                actorInstance.delete()
                flash.message = "actor.deleted"
                flash.args = [actorInstanceToString]
                flash.defaultMessage = "Actor ${actorInstanceToString} deleted"
                redirect(action: "list")
            }
            catch (org.hibernate.exception.ConstraintViolationException e) {
                flash.message = "actor.not.deleted"
                flash.args = [actorInstanceToString]
                flash.defaultMessage = "Actor ${actorInstanceToString} not deleted"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "actor.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Actor not found with id ${params.id}"
            redirect(action: "list")
        }
    }
}
