/* Copyright 2009 Marcel Overdijk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.grails.samples.sakila

class CountryController extends BaseController {

    def index = { redirect(action: "list", params: params) }
    
    static allowedMethods = [save: "POST", update: "POST", delete: "POST", search: "POST"]

    def list = {
        if (params.max) params.max = Math.min(params.max.toInteger(), 100)
        restoreState([max: 10, offset: 0, sort: "id", order: "asc", search: ""])
        def countryInstanceList = Country.createCriteria().list(params) {
            if (params.search) {
                ilike("country", "%${params.search}%")
            }
        }
        [countryInstanceList: countryInstanceList]
    }

    def search = {
        redirect(action: "list", params: [offset: 0, search: params.q])
    }

    def create = {
        def countryInstance = new Country()
        countryInstance.properties = params
        return [countryInstance: countryInstance]
    }

    def save = {
        def countryInstance = new Country(params)
        if (!countryInstance.hasErrors() && countryInstance.save()) {
            flash.message = "country.created"
            flash.args = [countryInstance]
            flash.defaultMessage = "Country ${countryInstance} created"
            redirect(action: "show", id: countryInstance.id)
        }
        else {
            render(view: "create", model: [countryInstance: countryInstance])
        }
    }

    def show = {
        def countryInstance = Country.get(params.id)
        if (!countryInstance) {
            flash.message = "country.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Country not found with id ${params.id}"
            redirect(action: "list")
        }
        else {
            return [countryInstance: countryInstance]
        }
    }

    def edit = {
        def countryInstance = Country.get(params.id)
        if (!countryInstance) {
            flash.message = "country.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Country not found with id ${params.id}"
            redirect(action: "list")
        }
        else {
            return [countryInstance: countryInstance]
        }
    }

    def update = {
        def countryInstance = Country.get(params.id)
        if (countryInstance) {
            countryInstance.properties = params
            if (!countryInstance.hasErrors() && countryInstance.save()) {
                flash.message = "country.updated"
                flash.args = [countryInstance]
                flash.defaultMessage = "Country ${countryInstance} updated"
                redirect(action: "show", id: countryInstance.id)
            }
            else {
                render(view: "edit", model: [countryInstance: countryInstance])
            }
        }
        else {
            flash.message = "country.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Country not found with id ${params.id}"
            redirect(action: "edit", id: params.id)
        }
    }

    def delete = {
        def countryInstance = Country.get(params.id)
        if (countryInstance) {
            def countryInstanceToString = countryInstance.toString()
            try {
                countryInstance.delete()
                flash.message = "country.deleted"
                flash.args = [countryInstanceToString]
                flash.defaultMessage = "Country ${countryInstanceToString} deleted"
                redirect(action: "list")
            }
            catch (org.hibernate.exception.ConstraintViolationException e) {
                flash.message = "country.not.deleted"
                flash.args = [countryInstanceToString]
                flash.defaultMessage = "Country ${countryInstanceToString} not deleted"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "country.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Country not found with id ${params.id}"
            redirect(action: "list")
        }
    }
}
