/* Copyright 2009 Marcel Overdijk
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.grails.samples.sakila

class LanguageController extends BaseController {

    def index = { redirect(action: "list", params: params) }
    
    static allowedMethods = [save: "POST", update: "POST", delete: "POST", search: "POST"]

    def list = {
        if (params.max) params.max = Math.min(params.max.toInteger(), 100)
        restoreState([max: 10, offset: 0, sort: "id", order: "asc", search: ""])
        def languageInstanceList = Language.createCriteria().list(params) {
            if (params.search) {
                ilike("name", "%${params.search}%")
            }
        }
        [languageInstanceList: languageInstanceList]
    }

    def search = {
        redirect(action: "list", params: [offset: 0, search: params.q])
    }

    def create = {
        def languageInstance = new Language()
        languageInstance.properties = params
        return [languageInstance: languageInstance]
    }

    def save = {
        def languageInstance = new Language(params)
        if (!languageInstance.hasErrors() && languageInstance.save()) {
            flash.message = "language.created"
            flash.args = [languageInstance]
            flash.defaultMessage = "Language ${languageInstance} created"
            redirect(action: "show", id: languageInstance.id)
        }
        else {
            render(view: "create", model: [languageInstance: languageInstance])
        }
    }

    def show = {
        def languageInstance = Language.get(params.id)
        if (!languageInstance) {
            flash.message = "language.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Language not found with id ${params.id}"
            redirect(action: "list")
        }
        else {
            return [languageInstance: languageInstance]
        }
    }

    def edit = {
        def languageInstance = Language.get(params.id)
        if (!languageInstance) {
            flash.message = "language.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Language not found with id ${params.id}"
            redirect(action: "list")
        }
        else {
            return [languageInstance: languageInstance]
        }
    }

    def update = {
        def languageInstance = Language.get(params.id)
        if (languageInstance) {
            languageInstance.properties = params
            if (!languageInstance.hasErrors() && languageInstance.save()) {
                flash.message = "language.updated"
                flash.args = [languageInstance]
                flash.defaultMessage = "Language ${languageInstance} updated"
                redirect(action: "show", id: languageInstance.id)
            }
            else {
                render(view: "edit", model: [languageInstance: languageInstance])
            }
        }
        else {
            flash.message = "language.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Language not found with id ${params.id}"
            redirect(action: "edit", id: params.id)
        }
    }

    def delete = {
        def languageInstance = Language.get(params.id)
        if (languageInstance) {
            def languageInstanceToString = languageInstance.toString()
            try {
                languageInstance.delete()
                flash.message = "language.deleted"
                flash.args = [languageInstanceToString]
                flash.defaultMessage = "Language ${languageInstanceToString} deleted"
                redirect(action: "list")
            }
            catch (org.hibernate.exception.ConstraintViolationException e) {
                flash.message = "language.not.deleted"
                flash.args = [languageInstanceToString]
                flash.defaultMessage = "Language ${languageInstanceToString} not deleted"
                redirect(action: "show", id: params.id)
            }
        }
        else {
            flash.message = "language.not.found"
            flash.args = [params.id]
            flash.defaultMessage = "Language not found with id ${params.id}"
            redirect(action: "list")
        }
    }
}
